createCohortMethodDataSimulationProfile: Create simulation profile

View source: R/Simulation.R

createCohortMethodDataSimulationProfileR Documentation

Create simulation profile

Description

Creates a profile based on the provided CohortMethodData object, which can be used to generate simulated data that has similar characteristics.

Usage

createCohortMethodDataSimulationProfile(cohortMethodData, minCellCount = 5)

Arguments

cohortMethodData

An object of type CohortMethodData as generated using getDbCohortMethodData().

minCellCount

If > 0, will set to zero all low-prevalence covariates in the supplied simulation table in order to prevent identification of persons.

Details

The output of this function is an object that can be used by the simulateCohortMethodData() function to generate a cohortMethodData object.

Value

An object of type CohortDataSimulationProfile.


CohortMethod documentation built on March 21, 2026, 5:06 p.m.