View source: R/SettingsObjects.R
| createMatchOnPsArgs | R Documentation |
matchOnPs()Create a parameter object for the function matchOnPs()
createMatchOnPsArgs(
caliper = 0.2,
caliperScale = "standardized logit",
maxRatio = 1,
allowReverseMatch = FALSE,
matchColumns = c(),
matchCovariateIds = c()
)
caliper |
The caliper for matching. A caliper is the distance which is acceptable for any match. Observations which are outside of the caliper are dropped. A caliper of 0 means no caliper is used. |
caliperScale |
The scale on which the caliper is defined. Three scales are supported:
|
maxRatio |
The maximum number of persons in the comparator arm to be matched to
each person in the treatment arm. A |
allowReverseMatch |
Allows n-to-1 matching if target arm is larger |
matchColumns |
Names or numbers of one or more columns in the |
matchCovariateIds |
One or more covariate IDs in the |
Create an object defining the parameter values.
An object of type MatchOnPsArgs.
Austin, PC. (2011) Optimal caliper widths for propensity-score matching when estimating differences in means and differences in proportions in observational studies, Pharmaceutical statistics, March, 10(2):150-161.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.