View source: R/SettingsObjects.R
| createStratifyByPsArgs | R Documentation |
stratifyByPs()Create a parameter object for the function stratifyByPs()
createStratifyByPsArgs(
numberOfStrata = 10,
baseSelection = "all",
stratificationColumns = c(),
stratificationCovariateIds = c()
)
numberOfStrata |
How many strata? The boundaries of the strata are automatically defined to contain equal numbers of target persons. |
baseSelection |
What is the base selection of subjects where the strata bounds are to be determined? Strata are defined as equally-sized strata inside this selection. Possible values are "all", "target", and "comparator". |
stratificationColumns |
Names or numbers of one or more columns in the |
stratificationCovariateIds |
One or more covariate IDs in the |
Create an object defining the parameter values.
An object of type StratifyByPsArgs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.