View source: R/SettingsObjects.R
| createTargetComparatorOutcomes | R Documentation |
Create target-comparator-outcomes combinations.
createTargetComparatorOutcomes(
targetId,
comparatorId,
outcomes,
nestingCohortId = NULL,
excludedCovariateConceptIds = c(),
includedCovariateConceptIds = c()
)
targetId |
A cohort ID identifying the target exposure in the exposure table. |
comparatorId |
A cohort ID identifying the comparator exposure in the exposure table. |
outcomes |
A list of object of type |
nestingCohortId |
(Optional) the nesting cohort ID. If provided, this will override
the nesting cohort ID used in |
excludedCovariateConceptIds |
A list of concept IDs that cannot be used to construct covariates. This argument is to be used only for exclusion concepts that are specific to the target-comparator combination. |
includedCovariateConceptIds |
A list of concept IDs that must be used to construct covariates. This argument is to be used only for inclusion concepts that are specific to the target-comparator combination. |
Create a set of hypotheses of interest, to be used with the runCmAnalyses() function.
An object of type TargetComparatorOutcomes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.