View source: R/SettingsObjects.R
| createTrimByPsArgs | R Documentation |
trimByPs()Create a parameter object for the function trimByPs()
createTrimByPsArgs(
trimFraction = NULL,
equipoiseBounds = NULL,
maxWeight = NULL,
trimMethod = "symmetric"
)
trimFraction |
For |
equipoiseBounds |
A 2-dimensional numeric vector containing the upper and lower bound on the preference score (Walker, 2013) for keeping persons. |
maxWeight |
The maximum allowed IPTW. |
trimMethod |
The trimming method to be performed. Three methods are supported:
|
Create an object defining the parameter values. Set any argument to NULL to not use it for
trimming.
An object of type TrimByPsArgs.
Walker AM, Patrick AR, Lauer MS, Hornbrook MC, Marin MG, Platt R, Roger VL, Stang P, and Schneeweiss S. (2013) A tool for assessing the feasibility of comparative effectiveness research, Comparative Effective Research, 3, 11-20
Crump, Richard K., V. Joseph Hotz, Guido W. Imbens, and Oscar A. Mitnik. 2009. Dealing with limited overlap in estimation of average treatment effects. Biometrika 96(1): 187-199.
Sturmer T, Rothman KJ, Avorn J, Glynn RJ. Treatment effects in the presence of unmeasured confounding: dealing with observations in the tails of the propensity score distribution–a simulation study. Am J Epidemiol. 2010 Oct 1;172(7):843-54.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.