getAttritionTable: Get the attrition table for a population

View source: R/StudyPopulation.R

getAttritionTableR Documentation

Get the attrition table for a population

Description

Get the attrition table for a population

Usage

getAttritionTable(object)

Arguments

object

Either an object of type CohortMethodData, a population object generated by functions like createStudyPopulation(), or an object of type outcomeModel.

Value

A tibble specifying the number of people and exposures in the population after specific steps of filtering.


CohortMethod documentation built on March 21, 2026, 5:06 p.m.