getFileReference: Get file reference

View source: R/RunAnalyses.R

getFileReferenceR Documentation

Get file reference

Description

Get file reference

Usage

getFileReference(outputFolder)

Arguments

outputFolder

Name of the folder where all the outputs have been written to.

Value

A tibble containing file names of artifacts generated for each target-comparator-outcome-analysis combination.


CohortMethod documentation built on March 21, 2026, 5:06 p.m.