View source: R/SettingsObjects.R
| createCmAnalysesSpecifications | R Documentation |
Create full CM analysis specifications
createCmAnalysesSpecifications(
cmAnalysisList,
targetComparatorOutcomesList,
analysesToExclude = NULL,
refitPsForEveryOutcome = FALSE,
refitPsForEveryStudyPopulation = TRUE,
cmDiagnosticThresholds = createCmDiagnosticThresholds()
)
cmAnalysisList |
A list of objects of type |
targetComparatorOutcomesList |
A list of objects of type |
analysesToExclude |
Analyses to exclude. See the Analyses to Exclude section for details. |
refitPsForEveryOutcome |
Should the propensity model be fitted for every outcome (i.e. after people who already had the outcome are removed)? If false, a single propensity model will be fitted, and people who had the outcome previously will be removed afterwards. |
refitPsForEveryStudyPopulation |
Should the propensity model be fitted for every study population definition? If false, a single propensity model will be fitted, and the study population criteria will be applied afterwards. |
cmDiagnosticThresholds |
An object of type |
Normally, runCmAnalyses will run all combinations of target-comparator-outcome-analyses settings.
However, sometimes we may not need all those combinations. Using the analysesToExclude argument,
we can remove certain items from the full matrix. This argument should be a data frame with at least
one of the following columns:
targetId
comparatorId
nestingCohortId
outcomeId
analysisId
This data frame will be joined to the outcome model reference table before executing, and matching rows will be removed. For example, if one specifies only one target ID and analysis ID, then any analyses with that target and that analysis ID will be skipped.
An object of type CmAnalysesSpecifications.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.