Skip to contents

Create a CohortMethod analysis specification

Usage

createCmAnalysis(
  analysisId = 1,
  description = "",
  getDbCohortMethodDataArgs,
  createStudyPopulationArgs,
  createPsArgs = NULL,
  trimByPsArgs = NULL,
  truncateIptwArgs = NULL,
  matchOnPsArgs = NULL,
  stratifyByPsArgs = NULL,
  computeSharedCovariateBalanceArgs = NULL,
  computeCovariateBalanceArgs = NULL,
  fitOutcomeModelArgs = NULL
)

Arguments

analysisId

An integer that will be used later to refer to this specific set of analysis choices.

description

A short description of the analysis.

getDbCohortMethodDataArgs

An object representing the arguments to be used when calling the getDbCohortMethodData() function.

createStudyPopulationArgs

An object representing the arguments to be used when calling the createStudyPopulation() function.

createPsArgs

An object representing the arguments to be used when calling the createPs() function.

trimByPsArgs

An object representing the arguments to be used when calling the trimByPs() function.

truncateIptwArgs

An object representing the arguments to be used when calling the truncateIptw() function.

matchOnPsArgs

An object representing the arguments to be used when calling the matchOnPs() function.

stratifyByPsArgs

An object representing the arguments to be used when calling the stratifyByPs() function.

computeSharedCovariateBalanceArgs

An object representing the arguments to be used when calling the computeCovariateBalance() function per target-comparator-analysis.

computeCovariateBalanceArgs

An object representing the arguments to be used when calling the computeCovariateBalance() function per target-comparator-outcome-analysis.

fitOutcomeModelArgs

An object representing the arguments to be used when calling the fitOutcomeModel() function.

Value

An object of type CmAnalysis, to be used with the runCmAnalyses function.

Details

Create a set of analysis choices, to be used with the runCmAnalyses() function.

Providing a NULL value for any of the argument applies the corresponding step will not be executed. For example, if createPsArgs = NULL, no propensity scores will be computed.