View source: R/SettingsObjects.R
| createCmAnalysis | R Documentation |
Create a CohortMethod analysis specification
createCmAnalysis(
analysisId = 1,
description = "",
getDbCohortMethodDataArgs,
createStudyPopulationArgs,
createPsArgs = NULL,
trimByPsArgs = NULL,
truncateIptwArgs = NULL,
matchOnPsArgs = NULL,
stratifyByPsArgs = NULL,
computeSharedCovariateBalanceArgs = NULL,
computeCovariateBalanceArgs = NULL,
fitOutcomeModelArgs = NULL
)
analysisId |
An integer that will be used later to refer to this specific set of analysis choices. |
description |
A short description of the analysis. |
getDbCohortMethodDataArgs |
An object representing the arguments to be used when calling
the |
createStudyPopulationArgs |
An object representing the arguments to be used when calling
the |
createPsArgs |
An object representing the arguments to be used when calling
the |
trimByPsArgs |
An object representing the arguments to be used when calling
the |
truncateIptwArgs |
An object representing the arguments to be used when calling
the |
matchOnPsArgs |
An object representing the arguments to be used when calling
the |
stratifyByPsArgs |
An object representing the arguments to be used when calling
the |
computeSharedCovariateBalanceArgs |
An object representing the arguments to be used when calling
the |
computeCovariateBalanceArgs |
An object representing the arguments to be used when calling
the |
fitOutcomeModelArgs |
An object representing the arguments to be used when calling
the |
Create a set of analysis choices, to be used with the runCmAnalyses() function.
Providing a NULL value for any of the argument applies the corresponding step will not be executed.
For example, if createPsArgs = NULL, no propensity scores will be computed.
An object of type CmAnalysis, to be used with the runCmAnalyses function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.