View source: R/SettingsObjects.R
| createCmDiagnosticThresholds | R Documentation |
Threshold used when calling exportToCsv() to determine if we pass or fail diagnostics.
createCmDiagnosticThresholds(
mdrrThreshold = 10,
easeThreshold = 0.25,
sdmThreshold = 0.1,
sdmAlpha = NULL,
equipoiseThreshold = 0.2,
generalizabilitySdmThreshold = 999
)
mdrrThreshold |
What is the maximum allowed minimum detectable relative risk (MDRR)? |
easeThreshold |
What is the maximum allowed expected absolute systematic error (EASE). |
sdmThreshold |
What is the maximum allowed standardized difference of mean (SDM)? If any covariate has an SDM exceeding this threshold, the diagnostic will fail. |
sdmAlpha |
What is the alpha for testing whether the absolute SDM exceeds
|
equipoiseThreshold |
What is the minimum required equipoise? |
generalizabilitySdmThreshold |
What is the maximum allowed standardized difference of mean (SDM)when comparing the population before and after PS adjustments? If the SDM is greater than this value, the diagnostic will fail. |
The sdmThreshold and sdmAlpha arguments are independent of the threshold and alpha
threshold provided to the createComputeCovariateBalanceArgs() function. The latter have no
impact on blinding and diagnostics reported in the export.
An object of type CmDiagnosticThresholds.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.