| createCohortMethodDataSimulationProfile | R Documentation |
Creates a profile based on the provided CohortMethodData object, which can be used to generate simulated data that has similar characteristics.
createCohortMethodDataSimulationProfile(cohortMethodData, minCellCount = 5)
cohortMethodData |
An object of type CohortMethodData as generated using
|
minCellCount |
If > 0, will set to zero all low-prevalence covariates in the supplied simulation table in order to prevent identification of persons. |
The output of this function is an object that can be used by the simulateCohortMethodData()
function to generate a cohortMethodData object.
An object of type CohortDataSimulationProfile.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.