| createPs | R Documentation |
Creates propensity scores and inverse probability of treatment weights (IPTW) using a regularized logistic regression.
createPs(
cohortMethodData,
population = NULL,
createPsArgs = createCreatePsArgs()
)
cohortMethodData |
An object of type CohortMethodData as generated using
|
population |
A data frame describing the population. This should at least have a
|
createPsArgs |
And object of type |
IPTW estimates either the average treatment effect (ate) or average treatment effect in the treated (att) using stabilized inverse propensity scores (Xu et al. 2010).
Xu S, Ross C, Raebel MA, Shetterly S, Blanchette C, Smith D. Use of stabilized inverse propensity scores as weights to directly estimate relative risk and its confidence intervals. Value Health. 2010;13(2):273-277. doi:10.1111/j.1524-4733.2009.00671.x
data(cohortMethodDataSimulationProfile)
cohortMethodData <- simulateCohortMethodData(cohortMethodDataSimulationProfile, n = 1000)
ps <- createPs(cohortMethodData, createPsArgs = createCreatePsArgs())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.