Create target-comparator-outcomes combinations.
Source:R/SettingsObjects.R
createTargetComparatorOutcomes.RdCreate target-comparator-outcomes combinations.
Arguments
- targetId
A cohort ID identifying the target exposure in the exposure table.
- comparatorId
A cohort ID identifying the comparator exposure in the exposure table.
- outcomes
A list of object of type
Outcomeas created bycreateOutcome().- nestingCohortId
(Optional) the nesting cohort ID. If provided, this will override the nesting cohort ID used in
createGetDbCohortMethodDataArgs().- excludedCovariateConceptIds
A list of concept IDs that cannot be used to construct covariates. This argument is to be used only for exclusion concepts that are specific to the target-comparator combination.
- includedCovariateConceptIds
A list of concept IDs that must be used to construct covariates. This argument is to be used only for inclusion concepts that are specific to the target-comparator combination.
Details
Create a set of hypotheses of interest, to be used with the runCmAnalyses() function.