Create an outcome model, and computes the relative risk
Usage
fitOutcomeModel(
population,
cohortMethodData = NULL,
fitOutcomeModelArgs = createFitOutcomeModelArgs()
)Arguments
- population
A population object generated by
createStudyPopulation(), potentially filtered by other functions.- cohortMethodData
An object of type CohortMethodData as generated using
getDbCohortMethodData(). Can be omitted if not using covariates and not using interaction terms.- fitOutcomeModelArgs
An object of type
FitOutcomeModelArgsas generated using thecreateFitOutcomeModelArgs()function.