fitOutcomeModel: Create an outcome model, and compute the relative risk

View source: R/OutcomeModels.R

fitOutcomeModelR Documentation

Create an outcome model, and compute the relative risk

Description

Create an outcome model, and computes the relative risk

Usage

fitOutcomeModel(
  population,
  cohortMethodData = NULL,
  fitOutcomeModelArgs = createFitOutcomeModelArgs()
)

Arguments

population

A population object generated by createStudyPopulation(), potentially filtered by other functions.

cohortMethodData

An object of type CohortMethodData as generated using getDbCohortMethodData(). Can be omitted if not using covariates and not using interaction terms.

fitOutcomeModelArgs

An object of type FitOutcomeModelArgs as generated using the createFitOutcomeModelArgs() function.

Details

For likelihood profiling, either specify the profileGrid for a completely user- defined grid, or profileBounds for an adaptive grid. Both should be defined on the log effect size scale. When both profileGrid and profileGrid are NULL likelihood profiling is disabled.

Value

An object of class OutcomeModel. Generic function print, coef, and confint are available.


CohortMethod documentation built on March 21, 2026, 5:06 p.m.