View source: R/OutcomeModels.R
| fitOutcomeModel | R Documentation |
Create an outcome model, and computes the relative risk
fitOutcomeModel(
population,
cohortMethodData = NULL,
fitOutcomeModelArgs = createFitOutcomeModelArgs()
)
population |
A population object generated by |
cohortMethodData |
An object of type CohortMethodData as generated using
|
fitOutcomeModelArgs |
An object of type |
For likelihood profiling, either specify the profileGrid for a completely user- defined grid, or
profileBounds for an adaptive grid. Both should be defined on the log effect size scale. When both
profileGrid and profileGrid are NULL likelihood profiling is disabled.
An object of class OutcomeModel. Generic function print, coef, and
confint are available.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.